<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */


if ( ! function_exists( 'personify_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Personify 0.1
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function personify_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'personify_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'personify_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Personify 0.1
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function personify_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'personify_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'personify_is_footer_detail_enable' ) ) :
	/**
	 * Check if footer detail is enabled.
	 *
	 * @since Personify 0.1
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function personify_is_footer_detail_enable( $control ) {
		return $control->manager->get_setting( 'personify_theme_options[footer_detail_enable]' )->value();
	}
endif;

if ( ! function_exists( 'personify_is_footer_name_enable' ) ) :
	/**
	 * Check if footer name is enabled.
	 *
	 * @since Personify 0.1
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function personify_is_footer_name_enable( $control ) {
		return personify_is_footer_detail_enable( $control ) && $control->manager->get_setting( 'personify_theme_options[footer_name_enable]' )->value();
	}
endif;


/* 
 * Front Page Setion
 */

/**
 * Check if introduction section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_introduction_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[introduction_section_enable]' )->value();
}

/**
 * Check if about section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_about_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[about_section_enable]' )->value();
}

/**
 * Check if featured posts section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_featured_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[featured_section_enable]' )->value();
}

/**
 * Check if quotation section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_quotation_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[quotation_section_enable]' )->value();
}

/**
 * Check if journey section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_journey_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[journey_section_enable]' )->value();
}

/**
 * Check if message section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_message_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[message_section_enable]' )->value();
}

/**
 * Check if event section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_event_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[event_section_enable]' )->value();
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Personify 0.1
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function personify_is_testimonial_section_enable( $control ) {
	return $control->manager->get_setting( 'personify_theme_options[testimonial_section_enable]' )->value();
}
