<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */

// Add Testimonial section
$wp_customize->add_section( 'personify_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial Section','personify' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'personify' ),
	'panel'             => 'personify_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'personify_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'personify_sanitize_switch_control',
) );

$wp_customize->add_control( new Personify_Switch_Control( $wp_customize, 'personify_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'personify' ),
	'section'           => 'personify_testimonial_section',
	'on_off_label' 		=> personify_enable_options(),
) ) );

// Testimonial title setting and control
$wp_customize->add_setting( 'personify_theme_options[testimonial_title]', array(
	'default' 			=> $options['testimonial_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'personify_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Testimonial Section Title', 'personify' ),
	'section'        	=> 'personify_testimonial_section',
	'active_callback' 	=> 'personify_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'personify_theme_options[testimonial_title]', array(
		'selector'            => '#client-testimonial .wrapper .section-header h2.section-title',
		'settings'            => 'personify_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'personify_testimonial_title_partial',
    ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'personify_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'personify_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Personify_Dropdown_Taxonomies_Control( $wp_customize,'personify_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'personify' ),
	'description'      	=> esc_html__( 'Note: Latest two testimonial post\'s content will be shown from selected category', 'personify' ),
	'section'           => 'personify_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'personify_is_testimonial_section_enable'
) ) );
