<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Personify 0.1
    */
    function personify_add_about_section() {
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'personify_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        personify_render_about_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_about_section', 20 );


if ( ! function_exists( 'personify_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Personify 0.1
    * @param array $input about section details.
    */
    function personify_get_about_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();

        $post_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'                 => $post_id,
            'posts_per_page'    => 1,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['sub_title'] = has_excerpt() ? get_the_excerpt() : '';
                $page_post['excerpt']   = wpautop( get_the_content() );

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'personify_filter_about_section_details', 'personify_get_about_section_details' );


if ( ! function_exists( 'personify_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Personify 0.1
   *
   */
   function personify_render_about_section( $content_details = array() ) {
        $options = personify_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="about-section" class="relative page-section <?php echo ( empty( $content['sub_title'] ) ) ? 'subtitle-disabled' : ''; ?>">
                <div class="wrapper">
                    <article id="post-02" class="hentry">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <header class="entry-header">
                                <h2 class="entry-title">
                                    <?php echo personify_santize_span( $content['title'] ); ?>
                                </h2>
                            </header>
                        <?php endif; ?>

                        <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                            <div class="entry-content">
                                <?php echo wp_kses_post( $content['excerpt'] ); ?>
                            </div><!-- .entry-content -->
                        <?php endif; 

                        if ( ! empty( $content['sub_title'] ) ) : ?>
                            <div class="description">
                                <?php echo wp_kses_post( $content['sub_title'] ); ?>
                            </div><!-- .description -->
                        <?php endif; ?>
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about-section -->
        <?php endforeach;
    }
endif;